@@ -2,11 +2,10 @@
 
 module Main (main) where
 
-import Test.Framework.Providers.HUnit
-import Test.Framework.Providers.QuickCheck2
-import Test.Framework.TH
 import Test.HUnit
 import Test.QuickCheck
+import Test.Hspec
+import Test.Hspec.QuickCheck
 import Web.Routes
 
 newtype ArticleId = ArticleId Int deriving (Eq, Show, Num, PathInfo, Arbitrary)
@@ -38,4 +37,7 @@ case_fromPathInfo =
          url    -> assertFailure $ "expected a Left, but got: " ++ show url
 
 main :: IO ()
-main = $defaultMainGenerator
+main = hspec $ do
+ prop "toPathInfo" case_toPathInfo
+ prop "fromPathInfo" case_fromPathInfo
+ prop "PathInfo_isomorphism"  prop_PathInfo_isomorphism
